@@ -355,8 +355,8 @@ module Kramdown
         8736 => ['$\angle$'],
         8743 => ['$\wedge$'],
         8744 => ['$\vee$'],
-        8745 => ['$\cup$'],
-        8746 => ['$\cap$'],
+        8745 => ['$\cap$'],
+        8746 => ['$\cup$'],
         8747 => ['$\int$'],
         8756 => ['$\therefore$', 'amssymb'],
         8764 => ['$\sim$'],
@@ -534,7 +534,11 @@ module Kramdown
         :laquo => '\guillemotleft{}', :raquo => '\guillemotright{}'
       } # :nodoc:
       def convert_typographic_sym(el, opts)
-        TYPOGRAPHIC_SYMS[el.value]
+        if (result = @options[:typographic_symbols][el.value])
+          escape(result)
+        else
+          TYPOGRAPHIC_SYMS[el.value]
+        end
       end
 
       def convert_smart_quote(el, opts)
